summaryrefslogtreecommitdiff
path: root/Platform
diff options
context:
space:
mode:
authorMichael D Kinney <michael.d.kinney@intel.com>2019-06-13 14:20:45 -0700
committerMichael D Kinney <michael.d.kinney@intel.com>2019-07-01 16:13:40 -0700
commitd655a4c81f2791e68352fc9c171d24ca62b52a70 (patch)
treeb14211f4e37da0e7ca5c14b1fef08a609016a938 /Platform
parent25c710cd36790f7fb0fb05674f7460ff4040a024 (diff)
Vlv2TbltDevicePkg/PlatformInitPei: Update MemoryTypeInformation
Reduce extra reboots when UEFI Shell is run followed by an OS boot. The extra reboot is due to use of EfiLoaderCode that exceeds the MemoryTypeInformation bin size. EfiLoaderCode should not be tracked. Remove all memory types that should not be tracked, and update the remaining bin sizes based on observed memory usage on an X64 DEBUG profile. Cc: Zailiang Sun <zailiang.sun@intel.com> Cc: Yi Qian <yi.qian@intel.com> Signed-off-by: Michael D Kinney <michael.d.kinney@intel.com> Reviewed-By: Zailiang Sun <zailiang.sun@intel.com>
Diffstat (limited to 'Platform')
-rw-r--r--Platform/Intel/Vlv2TbltDevicePkg/PlatformInitPei/MemoryPeim.c21
1 files changed, 5 insertions, 16 deletions
diff --git a/Platform/Intel/Vlv2TbltDevicePkg/PlatformInitPei/MemoryPeim.c b/Platform/Intel/Vlv2TbltDevicePkg/PlatformInitPei/MemoryPeim.c
index e6189b77..64b60663 100644
--- a/Platform/Intel/Vlv2TbltDevicePkg/PlatformInitPei/MemoryPeim.c
+++ b/Platform/Intel/Vlv2TbltDevicePkg/PlatformInitPei/MemoryPeim.c
@@ -1,10 +1,8 @@
/** @file
- Copyright (c) 2004 - 2016, Intel Corporation. All rights reserved.<BR>
-
- SPDX-License-Identifier: BSD-2-Clause-Patent
+ Copyright (c) 2004 - 2019, Intel Corporation. All rights reserved.<BR>
-
+ SPDX-License-Identifier: BSD-2-Clause-Patent
Module Name:
@@ -40,19 +38,10 @@ Abstract:
EFI_MEMORY_TYPE_INFORMATION mDefaultMemoryTypeInformation[] = {
{ EfiACPIReclaimMemory, 0x40 }, // 0x40 pages = 256k for ASL
- { EfiACPIMemoryNVS, 0x100 }, // 0x100 pages = 1 MB for S3, SMM, HII, etc
- { EfiReservedMemoryType, 0x600 }, // 48k for BIOS Reserved
- { EfiMemoryMappedIO, 0 },
- { EfiMemoryMappedIOPortSpace, 0 },
- { EfiPalCode, 0 },
- { EfiRuntimeServicesCode, 0x200 },
+ { EfiACPIMemoryNVS, 0x40 }, // 0x40 pages = 256k MB for S3, SMM, HII, etc
+ { EfiReservedMemoryType, 0x80 }, // 512k for BIOS Reserved
+ { EfiRuntimeServicesCode, 0x100 },
{ EfiRuntimeServicesData, 0x100 },
- { EfiLoaderCode, 0x100 },
- { EfiLoaderData, 0x100 },
- { EfiBootServicesCode, 0x800 },
- { EfiBootServicesData, 0x2500},
- { EfiConventionalMemory, 0 },
- { EfiUnusableMemory, 0 },
{ EfiMaxMemoryType, 0 }
};